@@ -2,7 +2,10 @@
 
 import os
 import re
-from typing import Optional, Any
+from typing import TYPE_CHECKING, Any, Optional
+
+if TYPE_CHECKING:
+    from edgar.ownership.core import Ownership
 
 import pandas as pd
 from jinja2 import Environment, FileSystemLoader
@@ -40,7 +43,7 @@ def format_address(street1: Optional[str], street2: Optional[str], city: Optiona
         parts.append(_escape_html(street1))
     if street2:
         parts.append(_escape_html(street2))
-    
+
     city_state_zip_line_parts = []
     if city:
         city_state_zip_line_parts.append(_escape_html(city))
@@ -48,19 +51,19 @@ def format_address(street1: Optional[str], street2: Optional[str], city: Optiona
         city_state_zip_line_parts.append(_escape_html(state))
     if zip_code:
         city_state_zip_line_parts.append(_escape_html(zip_code))
-    
+
     if city_state_zip_line_parts:
         parts.append(" ".join(city_state_zip_line_parts).strip())
-        
+
     return "<br>".join(part for part in parts if part)
 
 
 def ownership_to_html(ownership: 'Ownership') -> str:
     """Convert an Ownership object to HTML format matching official SEC layout.
-    
+
     Args:
         ownership: Ownership object containing SEC form data
-        
+
     Returns:
         HTML string representation
     """
@@ -68,10 +71,10 @@ def ownership_to_html(ownership: 'Ownership') -> str:
     template_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'templates')
     env = Environment(loader=FileSystemLoader(template_dir))
     template = env.get_template('ownership_form.html')
-    
+
     # Extract basic information and prepare context
     form_type = ownership.form
-    
+
     # Prepare context dictionary for template rendering
     context = {'form_type': form_type, 'html_title': f"SEC Form {form_type}", 'form_name_display': f"FORM {form_type}",
                'form_title_display': {
@@ -82,7 +85,7 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                'issuer_name': _escape_html(ownership.issuer.name if ownership.issuer else "N/A"),
                'ticker': _escape_html(ownership.issuer.ticker if ownership.issuer else "N/A"),
                'reporting_period': _format_date(ownership.reporting_period) if ownership.reporting_period else ''}
-    
+
     # Issuer information
 
     # Reporting owner information
@@ -96,17 +99,17 @@ def ownership_to_html(ownership: 'Ownership') -> str:
             reporting_owner.address.state_or_country if reporting_owner.address else None,
             reporting_owner.address.zipcode if reporting_owner.address else None
         )
-        
+
         # Reporting owner relationship
         context['is_director'] = 'X' if reporting_owner.is_director else ''
         context['is_officer'] = 'X' if reporting_owner.is_officer else ''
         context['is_ten_pct'] = 'X' if reporting_owner.is_ten_pct_owner else ''
         context['is_other'] = 'X' if reporting_owner.is_other else ''
         context['officer_title'] = _escape_html(reporting_owner.officer_title) if reporting_owner.officer_title else ''
-    
+
     # Remarks
     context['remarks'] = _escape_html(ownership.remarks) if ownership.remarks else ''
-    
+
     # Footnotes
     if ownership.footnotes and ownership.footnotes._footnotes:
         footnotes_list = []
@@ -115,19 +118,19 @@ def ownership_to_html(ownership: 'Ownership') -> str:
         context['footnotes_html'] = "\n".join(footnotes_list)
     else:
         context['footnotes_html'] = ''
-    
+
     # Signature
     if ownership.signatures and ownership.signatures.signatures:
         first_signature = ownership.signatures.signatures[0]
         if first_signature.signature:
             context['sig_name'] = _escape_html(first_signature.signature)
-        
+
         if first_signature.date:
             if isinstance(first_signature.date, str):
                 context['sig_date'] = _escape_html(_format_date(first_signature.date))
             else:
                 context['sig_date'] = _escape_html(str(first_signature.date))
-    
+
     # Process Table I - Non-Derivative Securities
     non_deriv_rows = []
     non_derivative_table = getattr(ownership, 'non_derivative_table', None)
@@ -137,16 +140,16 @@ def ownership_to_html(ownership: 'Ownership') -> str:
             for holding_tuple in non_derivative_table.holdings.data.itertuples(index=False):
                 # Convert tuple to dictionary for easier access with default values
                 holding = {col: getattr(holding_tuple, col, '') for col in holding_tuple._fields}
-                
+
                 # Extract values using dictionary get() with defaults
                 security_title = str(holding.get('Security', ''))
                 shares_owned = format_numeric(str(holding.get('Shares', '')))
                 direct_indirect_code = str(holding.get('DirectIndirect', ''))
                 nature_of_ownership = str(holding.get('NatureOfOwnership', ''))
-                
+
                 # Clean footnotes from values for table display
                 security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
-                
+
                 row = [
                     f'<td class="TableCell">{security_title_clean}</td>',
                     f'<td class="TableCell Right">{shares_owned}</td>',
@@ -154,13 +157,13 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     f'<td class="TableCell">{nature_of_ownership}</td>'
                 ]
                 non_deriv_rows.append(row)
-        
+
         # Form 4/5 - Transactions
         elif form_type in ['4', '5'] and hasattr(non_derivative_table, 'transactions') and non_derivative_table.transactions is not None and not non_derivative_table.transactions.empty:
             for transaction_tuple in non_derivative_table.transactions.data.itertuples(index=False):
                 # Convert tuple to dictionary for easier access with default values
                 transaction = {col: getattr(transaction_tuple, col, '') for col in transaction_tuple._fields}
-                
+
                 # Extract values using dictionary get() with defaults
                 security_title = str(transaction.get('Security', ''))
                 transaction_date = _format_date(transaction.get('Date', ''))
@@ -173,10 +176,10 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                 owned_after_transaction = format_numeric(str(transaction.get('Remaining', '')))
                 direct_indirect_code = str(transaction.get('DirectIndirect', ''))
                 nature_of_ownership = str(transaction.get('NatureOfOwnership', ''))
-                
+
                 # Clean footnotes from values for table display
                 security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
-                
+
                 row = [
                     f'<td class="TableCell">{security_title_clean}</td>',
                     f'<td class="TableCell">{transaction_date}</td>',
@@ -191,22 +194,22 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     f'<td class="TableCell">{nature_of_ownership}</td>'
                 ]
                 non_deriv_rows.append(row)
-            
+
             # Process Holdings for Forms 4/5
             if hasattr(non_derivative_table, 'holdings') and non_derivative_table.holdings is not None and not non_derivative_table.holdings.empty:
                 for holding_tuple in non_derivative_table.holdings.data.itertuples(index=False):
                     # Convert tuple to dictionary for easier access with default values
                     holding = {col: getattr(holding_tuple, col, '') for col in holding_tuple._fields}
-                    
+
                     # Extract values using dictionary get() with defaults
                     security_title = str(holding.get('Security', ''))
                     shares_owned = format_numeric(str(holding.get('Shares', '')))
                     direct_indirect_code = str(holding.get('DirectIndirect', ''))
                     nature_of_ownership = str(holding.get('NatureOfOwnership', ''))
-                    
+
                     # Clean footnotes from values for table display
                     security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
-                    
+
                     row = [
                         f'<td class="TableCell">{security_title_clean}</td>',
                         '<td class="TableCell"></td>',  # Transaction Date
@@ -221,7 +224,7 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                         f'<td class="TableCell">{nature_of_ownership}</td>'
                     ]
                     non_deriv_rows.append(row)
-    
+
     # Add non_deriv_rows to context
     context['non_deriv_rows'] = non_deriv_rows
 
@@ -234,7 +237,7 @@ def ownership_to_html(ownership: 'Ownership') -> str:
             for holding_tuple in derivative_table.holdings.data.itertuples(index=False):
                 # Convert tuple to dictionary for easier access with default values
                 holding = {col: getattr(holding_tuple, col, '') for col in holding_tuple._fields}
-                
+
                 # Extract values using dictionary get() with defaults
                 security_title = str(holding.get('Security', ''))
                 conversion_price = format_price(holding.get('ExercisePrice', ''))
@@ -246,12 +249,12 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                 title_amount_underlying = f"{underlying_title} - {underlying_shares}"
                 direct_indirect_code = holding.get('DirectIndirect', '')
                 nature_of_ownership = str(holding.get('Nature Of Ownership', ''))
-                
+
                 # Clean footnotes from values for table display
                 security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
                 exercisable_expiration_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', exercisable_expiration).strip()
                 title_amount_underlying_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', title_amount_underlying).strip()
-                
+
                 row = [
                     f'<td class="TableCell">{security_title_clean}</td>',
                     f'<td class="TableCell Right">{conversion_price}</td>',
@@ -269,13 +272,13 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     f'<td class="TableCell">{nature_of_ownership}</td>'
                 ]
                 deriv_rows.append(row)
-        
+
         # Form 4/5 - Derivative Transactions
         elif form_type in ['4', '5'] and hasattr(derivative_table, 'transactions') and derivative_table.transactions is not None and not derivative_table.transactions.empty:
             for transaction_tuple in derivative_table.transactions.data.itertuples(index=False):
                 # Convert tuple to dictionary for easier access with default values
                 transaction = {col: getattr(transaction_tuple, col, '') for col in transaction_tuple._fields}
-                
+
                 # Extract values using dictionary get() with defaults
                 security_title = str(transaction.get('Security', ''))
                 conversion_price = format_price(transaction.get('ExercisePrice', ''))
@@ -295,12 +298,12 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                 owned_after_transaction = format_numeric(str(transaction.get('Remaining', '')))
                 direct_indirect_code = str(transaction.get('DirectIndirect', ''))
                 nature_of_ownership = str(transaction.get('NatureOfOwnership', ''))
-                
+
                 # Clean footnotes from values for table display
                 security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
                 exercisable_expiration_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', exercisable_expiration).strip()
                 title_amount_underlying_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', title_amount_underlying).strip()
-                
+
                 row = [
                     f'<td class="TableCell">{security_title_clean}</td>',
                     f'<td class="TableCell Right">{conversion_price}</td>',
@@ -318,13 +321,13 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     f'<td class="TableCell">{nature_of_ownership}</td>'
                 ]
                 deriv_rows.append(row)
-            
+
             # Process Holdings for Forms 4/5
             if hasattr(derivative_table, 'holdings') and derivative_table.holdings:
                 for holding_tuple in derivative_table.holdings.data.itertuples(index=False):
                     # Convert tuple to dictionary for easier access with default values
                     holding = {col: getattr(holding_tuple, col, '') for col in holding_tuple._fields}
-                    
+
                     # Extract values using dictionary get() with defaults
                     security_title = str(holding.get('Security', ''))
                     conversion_price = format_price(holding.get('ExercisePrice', ''))
@@ -337,12 +340,12 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     owned_after_transaction = format_numeric(holding.get('Remaining', ''))
                     direct_indirect_code = holding.get('DirectIndirect', '')
                     nature_of_ownership = str(holding.get('NatureOfOwnership', ''))
-                    
+
                     # Clean footnotes from values for table display
                     security_title_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', security_title).strip()
                     exercisable_expiration_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', exercisable_expiration).strip()
                     title_amount_underlying_clean = re.sub(r'<[Ss][Uu][Pp]>.*?</[Ss][Uu][Pp]>', '', title_amount_underlying).strip()
-                    
+
                     row = [
                         f'<td class="TableCell">{security_title_clean}</td>',
                         f'<td class="TableCell Right">{conversion_price}</td>',
@@ -362,7 +365,7 @@ def ownership_to_html(ownership: 'Ownership') -> str:
                     deriv_rows.append(row)
     # Add deriv_rows to context
     context['deriv_rows'] = deriv_rows
-    
+
     # Render the template with the context
     return template.render(**context)
 
@@ -370,7 +373,7 @@ def _parse_name(name: str):
     """Parse a full name into (last, first, middle) components"""
     if not name:
         return '', '', ''
-    
+
     # Check for comma format: "Last, First Middle"
     if ',' in name:
         last, rest = name.split(',', 1)
@@ -383,5 +386,5 @@ def _parse_name(name: str):
         last = parts[-1] if parts else ''
         first = parts[0] if parts else ''
         middle = ' '.join(parts[1:-1]) if len(parts) > 1 else ''
-    
+
     return last.strip(), first.strip(), middle.strip()
