@@ -1,21 +1,22 @@
 import asyncio
 import os
 import re
-from datetime import datetime, date
+from datetime import date, datetime
 from pathlib import Path
-from typing import Optional, Union, List
+from typing import TYPE_CHECKING, List, Optional, Union
+
+if TYPE_CHECKING:
+    from edgar._filings import Filings
 
 import pandas as pd
 from bs4 import BeautifulSoup
-from httpx import HTTPStatusError, AsyncClient
+from httpx import AsyncClient, HTTPStatusError
 from tqdm.auto import tqdm
+
+from edgar.core import filing_date_to_year_quarters, get_edgar_data_directory, log, strtobool
 from edgar.dates import extract_dates
-from edgar.core import log, get_edgar_data_directory, filing_date_to_year_quarters, strtobool
 from edgar.httprequests import download_bulk_data, download_datafile, download_text
-from edgar.reference.tickers import (ticker_txt_url,
-                                     company_tickers_json_url,
-                                     mutual_fund_tickers_url,
-                                     company_tickers_exchange_url)
+from edgar.reference.tickers import company_tickers_exchange_url, company_tickers_json_url, mutual_fund_tickers_url, ticker_txt_url
 
 __all__ = ['download_edgar_data',
            'get_edgar_data_directory',
@@ -40,9 +41,9 @@ class DirectoryBrowsingNotAllowed(Exception):
 def use_local_storage(path_or_enable: Union[bool, str, Path, None] = True, use_local: Optional[bool] = None):
     """
     Enable or disable local storage, optionally setting the storage path.
-    
+
     This function supports multiple calling patterns for convenience:
-    
+
     Args:
         path_or_enable: Can be:
             - bool: Enable (True) or disable (False) local storage
@@ -50,22 +51,22 @@ def use_local_storage(path_or_enable: Union[bool, str, Path, None] = True, use_l
             - None: Use default behavior
         use_local: Optional boolean to explicitly set enable/disable state.
                   Only used when path_or_enable is a path.
-              
+
     Raises:
         FileNotFoundError: If path is provided but does not exist.
         NotADirectoryError: If path exists but is not a directory.
-        
+
     Examples:
         >>> # Simple enable/disable (backward compatible)
         >>> use_local_storage(True)
         >>> use_local_storage(False)
         >>> use_local_storage()  # defaults to True
-        
+
         >>> # Set path and enable (new intuitive syntax)
         >>> use_local_storage("~/Documents/edgar")
         >>> use_local_storage("/tmp/edgar_data")
         >>> use_local_storage(Path.home() / "edgar")
-        
+
         >>> # Set path and explicitly control enable/disable
         >>> use_local_storage("/tmp/edgar", True)   # enable
         >>> use_local_storage("/tmp/edgar", False)  # set path but disable
@@ -85,11 +86,11 @@ def use_local_storage(path_or_enable: Union[bool, str, Path, None] = True, use_l
         path = None
     else:
         raise TypeError(f"First parameter must be bool, str, Path, or None, got {type(path_or_enable)}")
-    
+
     # If a path is provided and we're enabling local storage, set the path first
     if path is not None and enable:
         set_local_storage_path(path)
-    
+
     # Set the local storage flag
     os.environ['EDGAR_USE_LOCAL_DATA'] = "1" if enable else "0"
 
@@ -104,18 +105,18 @@ def is_using_local_storage() -> bool:
 def set_local_storage_path(path: Union[str, Path]) -> None:
     """
     Set the local storage path for Edgar data.
-    
+
     This function provides a programmatic way to set the local storage directory,
     equivalent to setting the EDGAR_LOCAL_DATA_DIR environment variable.
-    
+
     Args:
         path: Path to the directory where Edgar data should be stored.
               Can be a string or Path object. The directory must already exist.
-              
+
     Raises:
         FileNotFoundError: If the specified directory does not exist.
         NotADirectoryError: If the path exists but is not a directory.
-              
+
     Example:
         >>> # First create the directory
         >>> os.makedirs("/tmp/edgar_data", exist_ok=True)
@@ -125,18 +126,18 @@ def set_local_storage_path(path: Union[str, Path]) -> None:
         >>> set_local_storage_path(Path.home() / "Documents")
     """
     from pathlib import Path
-    
+
     # Convert to Path object and resolve to absolute path
     storage_path = Path(path).expanduser().resolve()
-    
+
     # Validate that the directory exists
     if not storage_path.exists():
         raise FileNotFoundError(f"Directory does not exist: {storage_path}")
-    
+
     # Validate that it's actually a directory
     if not storage_path.is_dir():
         raise NotADirectoryError(f"Path exists but is not a directory: {storage_path}")
-    
+
     # Set the environment variable
     os.environ['EDGAR_LOCAL_DATA_DIR'] = str(storage_path)
 
@@ -153,7 +154,7 @@ def download_facts() -> Path:
     """
     Download company facts
     """
-    
+
     return asyncio.run(download_facts_async(client = None))
 
 async def download_submissions_async(client: Optional[AsyncClient]) -> Path:
@@ -245,7 +246,7 @@ def download_filings(filing_date: Optional[str] = None,
     if filings is not None:
         log.info('Using provided Filings object with %d filings', len(filings))
         accession_numbers = filings.data['accession_number'].to_pylist()
-        
+
         # If both filing_date and filings are provided, let the user know which takes precedence
         if filing_date:
             log.info('Both filing_date and filings parameters provided. Using filing_date %s for determining feed files to download.', filing_date)
@@ -265,7 +266,7 @@ def download_filings(filing_date: Optional[str] = None,
 
     # Get quarters to process
     year_and_quarters = filing_date_to_year_quarters(filing_date)
-    
+
     # Track statistics
     total_feed_files_downloaded = 0
     total_filings_kept = 0
@@ -291,18 +292,18 @@ def download_filings(filing_date: Optional[str] = None,
                 bulk_filing_file = row['File']
                 bulk_file_directory = data_directory / row['Name'][:8]
                 filing_date_str = row['Name'][:8]  # Extract YYYYMMDD from filename
-                
+
                 if not overwrite_existing:
                     if bulk_file_directory.exists():
                         log.warning('Skipping %s. Already exists', bulk_file_directory)
                         continue
-                
+
                 # Optimization: If we have specific accession numbers, check if all the ones 
                 # for this specific filing date already exist locally
                 if accession_numbers and filings is not None:
                     # Convert YYYYMMDD to YYYY-MM-DD format 
                     formatted_date = f"{filing_date_str[:4]}-{filing_date_str[4:6]}-{filing_date_str[6:8]}"
-                    
+
                     # Filter accession numbers to only those for this specific filing date
                     date_filtered_filings = filings.filter(filing_date=formatted_date)
                     if not date_filtered_filings.empty:
@@ -311,24 +312,24 @@ def download_filings(filing_date: Optional[str] = None,
                             log.warning('Not downloading for %s. All %d filings for this date already exist in local %s',
                                    formatted_date, len(date_accession_numbers), bulk_file_directory)
                             continue
-                
+
                 # Track existing files before extraction to preserve them during filtering
                 existing_files = set()
                 if accession_numbers and bulk_file_directory.exists():
                     existing_files = {str(f) for f in bulk_file_directory.glob('*.nc')}
-                
+
                 path = asyncio.run(download_bulk_data(client=None, url=bulk_filing_file, data_directory=data_directory))
                 log.info('Downloaded feed file to %s', path)
                 total_feed_files_downloaded += 1
-                
+
                 # If we have specific accession numbers, filter the extracted files
                 if accession_numbers and path.exists():
                     _filter_extracted_files._existing_files = existing_files
-                    
+
                     log.info('Filtering extracted files to keep only specified accession numbers')
                     filings_kept = _filter_extracted_files(path, accession_numbers, compress=compress, compression_level=compression_level)
                     total_filings_kept += filings_kept
-                    
+
                     # Clean up the tracking
                     if hasattr(_filter_extracted_files, '_existing_files'):
                         delattr(_filter_extracted_files, '_existing_files')
@@ -343,7 +344,7 @@ def download_filings(filing_date: Optional[str] = None,
                                 log.warning(f"Failed to compress {file_path}: {e}")
         else:
             log.info('No feed files found for %d Q%d in date range %s', year, quarter, filing_date)
-    
+
     # Log summary statistics
     log.info('Download complete. Downloaded %d feed files.', total_feed_files_downloaded)
     if accession_numbers:
@@ -355,42 +356,42 @@ def _filter_extracted_files(directory_path: Path, accession_numbers: List[str],
     Filter files in the extracted directory to keep only those matching the specified accession numbers.
     Files from the current extraction that don't match are removed to save disk space.
     Files that existed before this extraction (from previous downloads) are preserved.
-    
+
     Args:
         directory_path: Path to the directory containing extracted files
         accession_numbers: List of accession numbers to keep
         compress: Whether to compress the kept files (default: True)
         compression_level: Compression level for gzip (1-9, with 9 being highest compression)
-        
+
     Returns:
         int: Number of filings kept
     """
     if not directory_path.is_dir():
         return 0
-    
+
     # Convert accession numbers to the format used in filenames (removing dashes)
     normalized_accession_numbers = [an.replace('-', '') for an in accession_numbers]
-    
+
     # Keep track of which filings were found
     filings_kept = 0
-    
+
     # Get list of files that existed before this extraction
     # We'll preserve these even if they don't match our filter
     existing_files = getattr(_filter_extracted_files, '_existing_files', set())
-    
+
     # Find all .nc files in the directory
     for file_path in directory_path.glob('*.nc'):
         # Extract accession number from filename
         file_accession = file_path.stem
         undashed_accession = file_accession.replace('-', '')
-        
+
         # Check if this file matches our filter
         matches_filter = (undashed_accession in normalized_accession_numbers or 
                          file_accession in accession_numbers)
-        
+
         # Check if this file existed before this extraction
         was_preexisting = str(file_path) in existing_files
-        
+
         if matches_filter:
             filings_kept += 1
             # Compress the file if requested
@@ -408,7 +409,7 @@ def _filter_extracted_files(directory_path: Path, accession_numbers: List[str],
                 log.debug(f"Removed non-matching file from current extraction: {file_path}")
             except Exception as e:
                 log.warning(f"Failed to remove {file_path}: {e}")
-    
+
     return filings_kept
 
 
@@ -474,8 +475,8 @@ def get_sec_file_listing(url:str) -> pd.DataFrame:
             log.warning(f"There are no feed files for url {url}")
             return pd.DataFrame(columns=['Name', 'File', 'Size', 'Modified'])
         elif e.response.status_code == 404:
-            raise FileNotFoundError(f"Page not found: {url}")
-        raise ConnectionError(f"Failed to download page: {str(e)}")
+            raise FileNotFoundError(f"Page not found: {url}") from None
+        raise ConnectionError(f"Failed to download page: {str(e)}") from e
 
     if "Directory Browsing Not Allowed" in html:
         log.warning(f"Directory browsing is not allowed for {url}")
@@ -574,10 +575,10 @@ def latest_filing_date():
 def is_compressed_file(file_path: Path) -> bool:
     """
     Check if a file is gzip-compressed by examining its extension.
-    
+
     Args:
         file_path: Path to the file
-        
+
     Returns:
         bool: True if the file has a .gz extension, False otherwise
     """
@@ -587,54 +588,54 @@ def is_compressed_file(file_path: Path) -> bool:
 def compress_filing(file_path: Path, compression_level: int = 6, delete_original: bool = True) -> Path:
     """
     Compress a filing file using gzip and optionally delete the original.
-    
+
     Args:
         file_path: Path to the file to compress
         compression_level: Compression level (1-9, with 9 being highest compression)
         delete_original: Whether to delete the original file after compression
-        
+
     Returns:
         Path to the compressed file
-    
+
     Raises:
         FileNotFoundError: If the file does not exist
         ValueError: If the file is already compressed
     """
     import gzip
     import shutil
-    
+
     if not file_path.exists():
         raise FileNotFoundError(f"File not found: {file_path}")
-    
+
     if is_compressed_file(file_path):
         raise ValueError(f"File is already compressed: {file_path}")
-    
+
     compressed_path = Path(f"{file_path}.gz")
-    
+
     # Compress the file
     with file_path.open('rb') as f_in:
         with gzip.open(compressed_path, 'wb', compresslevel=compression_level) as f_out:
             shutil.copyfileobj(f_in, f_out)
-    
+
     # Delete the original file if requested
     if delete_original:
         file_path.unlink()
-    
+
     return compressed_path
 
 
 def decompress_filing(file_path: Path, output_path: Optional[Path] = None, delete_original: bool = False) -> Path:
     """
     Decompress a gzip-compressed filing file.
-    
+
     Args:
         file_path: Path to the compressed file
         output_path: Path to save the decompressed file (if None, use the original path without .gz)
         delete_original: Whether to delete the original compressed file
-        
+
     Returns:
         Path to the decompressed file
-    
+
     Raises:
         FileNotFoundError: If the file does not exist
         ValueError: If the file is not compressed
@@ -642,44 +643,44 @@ def decompress_filing(file_path: Path, output_path: Optional[Path] = None, delet
     """
     import gzip
     import shutil
-    
+
     if not file_path.exists():
         raise FileNotFoundError(f"File not found: {file_path}")
-    
+
     if not is_compressed_file(file_path):
         raise ValueError(f"File is not compressed: {file_path}")
-    
+
     # Determine output path if not provided
     if output_path is None:
         # Remove .gz extension
         output_path = Path(str(file_path)[:-3])
-    
+
     # Decompress the file
     with gzip.open(file_path, 'rb') as f_in:
         with output_path.open('wb') as f_out:
             shutil.copyfileobj(f_in, f_out)
-    
+
     # Delete the original compressed file if requested
     if delete_original:
         file_path.unlink()
-    
+
     return output_path
 
 
 def compress_all_filings(data_directory: Optional[Path] = None, compression_level: int = 6) -> int:
     """
     Compress all uncompressed filing files in the data directory.
-    
+
     Args:
         data_directory: Path to the data directory (defaults to the Edgar data directory)
         compression_level: Compression level (1-9, with 9 being highest compression)
-        
+
     Returns:
         Number of files compressed
     """
     if data_directory is None:
         data_directory = get_edgar_data_directory() / 'filings'
-    
+
     # Find all .nc files (not already compressed)
     files_compressed = 0
     for file_path in tqdm(list(data_directory.glob('**/*.nc')), desc="Compressing files"):
@@ -689,29 +690,29 @@ def compress_all_filings(data_directory: Optional[Path] = None, compression_leve
                 files_compressed += 1
             except Exception as e:
                 log.warning(f"Failed to compress {file_path}: {e}")
-    
+
     return files_compressed
 
 def check_filings_exist_locally(filing_date: Union[str, date], accession_numbers: List[str]) -> bool:
     """
     Check if all specified accession numbers already exist locally for a given filing date.
-    
+
     Args:
         filing_date: The filing date (YYYY-MM-DD format)
         accession_numbers: List of accession numbers to check
-        
+
     Returns:
         bool: True if all filings exist locally, False otherwise
     """
     if not accession_numbers:
         return False
-        
+
     for accession_number in accession_numbers:
         # Check both compressed and uncompressed versions
         filing_path = local_filing_path(filing_date, accession_number)
         if not filing_path.exists():
             return False
-    
+
     return True
 
 
@@ -721,21 +722,21 @@ def local_filing_path(filing_date:Union[str, date],
     """
     Get the local path for a filing
     If correction is True, will look for the corrected filing with extension 'corr'
-    
+
     Returns the compressed version (.gz) if it exists, otherwise returns the uncompressed path.
     """
     ext = 'corr' if correction else 'nc'
     if isinstance(filing_date, date):
         filing_date = filing_date.strftime('%Y-%m-%d')
     filing_date = filing_date.replace('-', '')
-    
+
     # Base path without compression extension
     base_path = get_edgar_data_directory() / 'filings' / filing_date / f"{accession_number}.{ext}"
-    
+
     # Check for compressed version first
     compressed_path = Path(f"{base_path}.gz")
     if compressed_path.exists():
         return compressed_path
-    
+
     # Fall back to uncompressed version
     return base_path
